Changelog
=========

0.x (`master`_)
~~~~~~~~~~~~~~~

.. note:: This version is not yet released and is under development.

0.6 (2021-04-20)
~~~~~~~~~~~~~~~~

* Drop Python 2.7 support
* Replace Travis CI with GitHub Actions
* Change ThreadedHTTPServer to HTTPServer for tests
* Add CodeQL CI tests
* Add pre-commit
* Improve build steps


0.5 (2021-04-14)
~~~~~~~~~~~~~~~~

* Add support to retry a failed request
* Improve test handlers to fix issues with Py2.7 and PyPy
* Improve tests
* Add Support for Python 3.6
* Add function to handle remark tags and elements
* Add support to parse data from ET.Element
* Move attribute modifiers from class to package
* Change to use Exception instead of BaseException

0.4 (2016-12-08)
~~~~~~~~~~~~~~~~

* Add SAX parser
* Add option to choose DOM or SAX parser
* Fix issues with CI builds with Python 3.2
* Add Python 3.5 to CI builds
* Fix issues (Thanks to all contributors)
* Add property for default API URL
* Add examples
* Build Fixes
* GitHub templates
* Parse center information
* Parse geometry information
* Support Areas

0.3.1 (2015-04-30)
~~~~~~~~~~~~~~~~~~

* Improve example

0.3.0 (2015-04-30)
~~~~~~~~~~~~~~~~~~

* Improve internal data handling (Dominik)
* Add helper functions (Morris Jobke)

0.2.0 (2014-12-27)
~~~~~~~~~~~~~~~~~~

* Added support for xml response data
* Added support for exceptions
* Added tests with 100% code coverage
* Removed Python 2.6 support
* Added more examples to the documentation

0.1.0 (2014-12-14)
~~~~~~~~~~~~~~~~~~

Proof of concept

* Initial release.

.. _`master`: https://github.com/DinoTools/python-overpy
